# Copyright (c) 2024 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.

import json
from argparse import ArgumentParser
from os import environ
from sys import stderr
from typing import Optional

from accelbyte_py_sdk import AccelByteSDK
from accelbyte_py_sdk.core import MyConfigRepository, InMemoryTokenRepository
import accelbyte_py_sdk.services.auth as auth_service


def parse_args() -> dict:
    parser = ArgumentParser(
        prog="python -m accelbyte_py_sdk",
    )

    subparsers = parser.add_subparsers(
        dest="command",
        required=True,
        help="command to use",
    )

    info = subparsers.add_parser(name="info")

    login = subparsers.add_parser(name="login")
    login.add_argument(
        "type",
        choices=(
            "client",
            "user",
        ),
    )
    login.add_argument(
        "-b", "--base-url", default=environ.get("AB_BASE_URL", None), dest="base_url"
    )
    login.add_argument("-n", "--namespace", default=environ.get("AB_NAMESPACE", None))
    login.add_argument(
        "-c", "--client-id", default=environ.get("AB_CLIENT_ID", None), dest="client_id"
    )
    login.add_argument(
        "-s",
        "--client-secret",
        default=environ.get("AB_CLIENT_SECRET", None),
        dest="client_secret",
    )
    login.add_argument("-u", "--username", default=environ.get("AB_USERNAME", None))
    login.add_argument("-p", "--password", default=environ.get("AB_PASSWORD", None))
    return vars(parser.parse_args())


def main(command: str, **kwargs) -> None:
    command = command.casefold()
    if command == "info":
        return info_command(**kwargs)
    elif command == "login":
        return login_command(**kwargs)
    else:
        exit(f"invalid command: {command}")


def info_command(**kwargs) -> None:
    from accelbyte_py_sdk import __product__, __version__

    print(f"{__product__} ({__version__})")


def login_command(
    type: str,
    base_url: Optional[str] = None,
    namespace: Optional[str] = None,
    client_id: Optional[str] = None,
    client_secret: Optional[str] = None,
    username: Optional[str] = None,
    password: Optional[str] = None,
    **kwargs,
) -> None:
    if not base_url:
        exit(
            f"[erro] base url not set, have you using -b/--base-url or setting AB_BASE_URL?"
        )
    if namespace is None:
        print(
            "[warn] namespace not set, "
            "did you forget using -n/--namespace or setting AB_NAMESPACE? "
            "- defaulting to 'accelbyte'",
            file=stderr,
        )
        namespace = "accelbyte"
    if not client_id:
        exit(
            f"[erro] client id not set, have you using -c/--client-id or setting AB_CLIENT_ID?"
        )
    if client_secret is None:
        print(
            "[warn] client secret not set, "
            "did you forget using -s/--client-secret or setting AB_CLIENT_SECRET?",
            file=stderr,
        )
        client_secret = ""

    config_repo = MyConfigRepository(base_url, client_id, client_secret, namespace)
    token_repo = InMemoryTokenRepository()
    sdk = AccelByteSDK()
    sdk.initialize(options={"config": config_repo, "token": token_repo})

    if type == "client":
        token, error = auth_service.login_client(client_id, client_secret, sdk=sdk)
        if error:
            exit(f"[erro] {error}")

    elif type == "user":
        if not username:
            exit(
                f"[erro] username not set, have you using -u/--username or setting AB_USERNAME?"
            )
        if not password:
            exit(
                f"[erro] password not set, have you using -p/--password or setting AB_PASSWORD?"
            )

        token, error = auth_service.login_user(username, password, sdk=sdk)
        if error:
            exit(f"[erro] {error}")
    else:
        raise ValueError(type)

    print(json.dumps(token.to_dict(), indent=2))


if __name__ == "__main__":
    main(**parse_args())


__all__ = []



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Platform Service."""

__version__ = "6.0.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .bulk_credit import BulkCredit
from .bulk_debit import BulkDebit
from .check_balance import CheckBalance
from .check_wallet import CheckWallet
from .check_wallet import OriginEnum as CheckWalletOriginEnum
from .credit_user_wallet import CreditUserWallet
from .debit_by_wallet_platform import DebitByWalletPlatform
from .debit_user_wallet import DebitUserWallet
from .debit_user_wallet_by_cu_54daab import DebitUserWalletByCurrencyCode
from .disable_user_wallet import DisableUserWallet
from .enable_user_wallet import EnableUserWallet
from .get_platform_wallet_config import GetPlatformWalletConfig
from .get_platform_wallet_config import (
    PlatformEnum as GetPlatformWalletConfigPlatformEnum,
)
from .get_user_wallet import GetUserWallet
from .get_wallet import GetWallet
from .list_user_currency_tran_bb67cf import ListUserCurrencyTransactions
from .list_user_wallet_transactions import ListUserWalletTransactions
from .pay_with_user_wallet import PayWithUserWallet
from .public_get_my_wallet import PublicGetMyWallet
from .public_get_wallet import PublicGetWallet
from .public_list_user_wallet_ed4de4 import PublicListUserWalletTransactions
from .query_user_currency_wallets import QueryUserCurrencyWallets
from .query_wallets import QueryWallets
from .query_wallets import OriginEnum as QueryWalletsOriginEnum
from .reset_platform_wallet_config import ResetPlatformWalletConfig
from .reset_platform_wallet_config import (
    PlatformEnum as ResetPlatformWalletConfigPlatformEnum,
)
from .update_platform_wallet_config import UpdatePlatformWalletConfig
from .update_platform_wallet_config import (
    PlatformEnum as UpdatePlatformWalletConfigPlatformEnum,
)



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Inventory Service."""

__version__ = "0.2.7"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_create_inventory import AdminCreateInventory
from .admin_get_inventory import AdminGetInventory
from .admin_list_inventories import AdminListInventories
from .admin_list_inventories import SortByEnum as AdminListInventoriesSortByEnum
from .admin_purchasable import AdminPurchasable
from .admin_update_inventory import AdminUpdateInventory
from .admin_update_user_inven_6f94a4 import AdminUpdateUserInventoriesByInventoryCode
from .delete_inventory import DeleteInventory



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Dsm Controller Service."""

__version__ = "6.8.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .add_port import AddPort
from .clear_cache import ClearCache
from .create_config import CreateConfig
from .delete_config import DeleteConfig
from .delete_port import DeletePort
from .export_config_v1 import ExportConfigV1
from .get_config import GetConfig
from .import_config_v1 import ImportConfigV1
from .list_config import ListConfig
from .save_config import SaveConfig
from .update_config import UpdateConfig
from .update_port import UpdatePort



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Inventory Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.apimodels_bulk_save_item_error import ApimodelsBulkSaveItemError
from ..models.apimodels_item_resp import ApimodelsItemResp


class ApimodelsBulkSaveItemResp(Model):
    """Apimodels bulk save item resp (apimodels.BulkSaveItemResp)

    Properties:
        success: (success) REQUIRED bool

        error_details: (errorDetails) OPTIONAL ApimodelsBulkSaveItemError

        item: (item) OPTIONAL ApimodelsItemResp
    """

    # region fields

    success: bool  # REQUIRED
    error_details: ApimodelsBulkSaveItemError  # OPTIONAL
    item: ApimodelsItemResp  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_success(self, value: bool) -> ApimodelsBulkSaveItemResp:
        self.success = value
        return self

    def with_error_details(
        self, value: ApimodelsBulkSaveItemError
    ) -> ApimodelsBulkSaveItemResp:
        self.error_details = value
        return self

    def with_item(self, value: ApimodelsItemResp) -> ApimodelsBulkSaveItemResp:
        self.item = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "success"):
            result["success"] = bool(self.success)
        elif include_empty:
            result["success"] = False
        if hasattr(self, "error_details"):
            result["errorDetails"] = self.error_details.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["errorDetails"] = ApimodelsBulkSaveItemError()
        if hasattr(self, "item"):
            result["item"] = self.item.to_dict(include_empty=include_empty)
        elif include_empty:
            result["item"] = ApimodelsItemResp()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        success: bool,
        error_details: Optional[ApimodelsBulkSaveItemError] = None,
        item: Optional[ApimodelsItemResp] = None,
        **kwargs,
    ) -> ApimodelsBulkSaveItemResp:
        instance = cls()
        instance.success = success
        if error_details is not None:
            instance.error_details = error_details
        if item is not None:
            instance.item = item
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsBulkSaveItemResp:
        instance = cls()
        if not dict_:
            return instance
        if "success" in dict_ and dict_["success"] is not None:
            instance.success = bool(dict_["success"])
        elif include_empty:
            instance.success = False
        if "errorDetails" in dict_ and dict_["errorDetails"] is not None:
            instance.error_details = ApimodelsBulkSaveItemError.create_from_dict(
                dict_["errorDetails"], include_empty=include_empty
            )
        elif include_empty:
            instance.error_details = ApimodelsBulkSaveItemError()
        if "item" in dict_ and dict_["item"] is not None:
            instance.item = ApimodelsItemResp.create_from_dict(
                dict_["item"], include_empty=include_empty
            )
        elif include_empty:
            instance.item = ApimodelsItemResp()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsBulkSaveItemResp]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsBulkSaveItemResp]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsBulkSaveItemResp,
        List[ApimodelsBulkSaveItemResp],
        Dict[Any, ApimodelsBulkSaveItemResp],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "success": "success",
            "errorDetails": "error_details",
            "item": "item",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "success": True,
            "errorDetails": False,
            "item": False,
        }

    # endregion static methods



# Copyright (c) 2024 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.

import binascii
import base64
import os
import hashlib
import json

from base64 import b64encode
from time import time
from typing import Any, Dict, List, Optional, Tuple, Union
from urllib.parse import quote

from ._http_response import HttpResponse

QUERY_DELIMITER_MAP = {
    "csv": ",",
    "ssv": " ",
    "tsv": "\t",
    "pipes": "|",
}


def clean_content_type(content_type: Optional[str]) -> Optional[str]:
    if content_type is None:
        return None
    clean_content_type_map = {"application/problem+json": "application/json"}
    parts = content_type.split(";", maxsplit=1)
    content_type = parts[0].strip()
    if content_type in clean_content_type_map:
        content_type = clean_content_type_map[content_type]
    return content_type


def create_basic_authentication(
    username: str, password: Optional[str], prefix: str = "Basic "
) -> str:
    password = password or ""
    return (
        f'{prefix}{b64encode(f"{username}:{password}".encode("utf-8")).decode("utf-8")}'
    )


def create_curl_request(
    uri: str, method: str, headers: Dict[str, str], data: Any, delimiter: str = "\n"
):
    parts = [f'curl -X {method} "{uri}"']
    for k, v in headers.items():
        parts.append(f'-H "{k}: {v}"')
    if data:
        parts.append(f"-d '{data}'")
    result = delimiter.join(parts)
    return result


def create_pkce_verifier_and_challenge_plain(
    size: int = 32, encoding: str = "ascii"
) -> Tuple[str, str, str]:
    method = "plain"
    verifier_bytes = os.urandom(size)
    verifier_base64 = base64.urlsafe_b64encode(verifier_bytes).rstrip(b"=")
    verifier_str = verifier_base64.decode(encoding)
    return verifier_str, verifier_str, method


def create_pkce_verifier_and_challenge_s256(
    size: int = 32, encoding: str = "ascii"
) -> Tuple[str, str, str]:
    method = "S256"
    verifier_bytes = os.urandom(size)
    verifier_base64 = base64.urlsafe_b64encode(verifier_bytes).rstrip(b"=")
    verifier_str = verifier_base64.decode(encoding)
    challenge_bytes = hashlib.sha256(verifier_base64).digest()
    challenge_base64 = base64.urlsafe_b64encode(challenge_bytes).rstrip(b"=")
    challenge_str = challenge_base64.decode(encoding)
    return verifier_str, challenge_str, method


def create_url(
    path: str,
    base: str = "",
    path_params: Optional[Dict[str, str]] = None,
    query_params: Optional[Dict[str, Union[Any, List[Any]]]] = None,
    collection_format_map: Optional[Dict[str, Optional[str]]] = None,
) -> str:
    result = base.removesuffix("/")

    if path_params:
        for key, value in path_params.items():
            path = path.replace(f"{{{key}}}", str(value))

    result += "/" + path.removeprefix("/")

    if query_params:
        flattened_query_params = flatten_query_params(
            query_params=query_params, collection_format_map=collection_format_map
        )
        result += flattened_query_params

    return result


def flatten_query_params(
    query_params: Optional[Dict[str, Union[Any, List[Any]]]] = None,
    collection_format_map: Optional[Dict[str, Optional[str]]] = None,
) -> str:
    def str_quote(o):
        return quote(str(o), safe="")

    if not query_params:
        return ""
    if collection_format_map is None:
        collection_format_map = {}
    flattened_query_params = []
    for key, value in query_params.items():
        if isinstance(value, list):
            if len(value) == 0:
                continue
            collection_format = collection_format_map.get(key, "csv")
            if collection_format == "multi":
                for v in value:
                    flattened_query_params.append((key, str_quote(v)))
            else:
                delimiter = QUERY_DELIMITER_MAP.get(collection_format, ",")
                flattened_query_value = delimiter.join([str_quote(v) for v in value])
                flattened_query_params.append((key, flattened_query_value))
        else:
            flattened_query_params.append((key, str_quote(value)))
    return "?" + "&".join(f"{k}={v}" for k, v in flattened_query_params)


def generate_amazon_xray_trace_id(
    version: int = 1, request_time: Union[None, float] = None
) -> str:
    request_time = request_time or time()
    current_time_hex = hex(int(request_time))[
        2:
    ]  # time of the original request, in Unix epoch time, in 8 hexadecimal digits
    request_id = binascii.hexlify(os.urandom(12)).decode(
        "utf-8"
    )  # 96-bit guid, in 24 hexadecimal digits
    return f"{version}-{current_time_hex}-{request_id}"  # see: https://docs.aws.amazon.com/xray/latest/devguide/xray-api-sendingdata.html


def get_query_from_http_redirect_response(
    http_response: HttpResponse, query_key: str
) -> Tuple[Union[None, str], Union[None, HttpResponse]]:
    if http_response.content_type != "location":
        return None, HttpResponse.create_error(
            http_response.code, "Can't find 'Location' in Header."
        )
    query = http_response.get_query_params()
    if query_key not in query:
        error_related_keys = [
            "error",
            "error_code",
            "error_description",
            "error_message",
        ]
        if any(q in error_related_keys for q in query):
            error_parts = []
            if "error" in query:
                error_parts.append(f"[{str(query['error'][0])}]")
            elif "error_code" in query:
                error_parts.append(f"[{str(query['error_code'][0])}]")
            if "error_description" in query:
                error_parts.append(str(query["error_description"][0]))
            elif "error_message" in query:
                error_parts.append(str(query["error_message"][0]))
            return None, HttpResponse.create_error(
                http_response.code, " ".join(error_parts)
            )
        return None, HttpResponse.create_error(
            http_response.code, f"Can't find '{query_key}' in query."
        )
    query_value = str(query[query_key][0])
    return query_value, None


def is_file(key: Union[str, Tuple[str, str]], value: Any) -> bool:
    if isinstance(key, tuple):
        key_name, key_type = key
        return key_type == "file"
    return key.casefold() == "file"


def is_json_mime_type(content_type: Optional[str]) -> bool:
    if content_type is None:
        return False
    parts = [x.strip() for x in content_type.split(";")]
    for part in parts:
        if "/" not in part:
            continue
        subparts = part.split("/", maxsplit=1)
        if len(subparts) != 2:
            continue
        p0, p1 = subparts
        if p0 != "application":
            continue
        if p1 == "json" or p1.endswith("+json"):
            return True
    return False


def try_convert_content_type(
    actual_content_type: str, expected_content_types: List[str], content: Any
) -> Tuple[bool, Any, Optional[str]]:
    same_content_type = {
        "application/zip": ("application/x-zip-compressed",),
    }
    errors = []
    for expected_content_type in expected_content_types:
        if (
            expected_content_type in same_content_type
            and actual_content_type in same_content_type[expected_content_type]
        ):
            return True, content, None
        if actual_content_type == "text/plain":
            if expected_content_type == "application/json":
                # noinspection PyBroadException
                # pylint: disable=broad-except
                try:
                    new_content = json.loads(content)
                    return True, new_content, None
                except Exception as error:
                    errors.append(str(error))
    errors.insert(0, f"{content=}\n")
    return False, content, "\n".join(errors)



from datetime import timedelta
from typing import Optional, Protocol, Tuple, Union


class HttpRetryPolicy(Protocol):
    def __call__(
        self,
        request,
        response,
        /,
        *,
        retries: int = 0,
        elapsed: Optional[timedelta] = None,
        **kwargs,
    ) -> bool:
        ...


class CompositeHttpRetryPolicy:
    def __init__(self, *policies: HttpRetryPolicy):
        self.policies = list(policies)

    def __call__(
        self,
        request,
        response,
        /,
        *,
        retries: int = 0,
        elapsed: Optional[timedelta] = None,
        **kwargs,
    ) -> bool:
        if elapsed is None:
            elapsed = timedelta(0)
        for policy in self.policies:
            result = policy(
                request, response, retries=retries, elapsed=elapsed, **kwargs
            )
            if not result:
                return False
        return True


class MaxElapsedHttpRetryPolicy:
    def __init__(self, max_elapsed: Union[int, float, timedelta]):
        if isinstance(max_elapsed, (int, float)):
            max_elapsed = timedelta(seconds=max_elapsed)
        self.max_elapsed = max_elapsed

    def __call__(
        self,
        request,
        response,
        /,
        *,
        retries: int = 0,
        elapsed: Optional[timedelta] = None,
        **kwargs,
    ) -> bool:
        if elapsed is None:
            elapsed = timedelta(0)
        return elapsed < self.max_elapsed


class MaxRetriesHttpRetryPolicy:
    def __init__(self, max_retries: int):
        self.max_retries = max_retries

    def __call__(
        self,
        request,
        response,
        /,
        *,
        retries: int = 0,
        elapsed: Optional[timedelta] = None,
        **kwargs,
    ) -> bool:
        return retries < self.max_retries


class NoHttpRetryPolicy:
    def __call__(
        self,
        request,
        response,
        /,
        *,
        retries: int = 0,
        elapsed: Optional[timedelta] = None,
        **kwargs,
    ) -> bool:
        return False


class StatusCodesHttpRetryPolicy:
    def __init__(self, *status_codes: Union[int, Tuple[int, int]]):
        self.status_codes = set()
        for element in status_codes:
            if isinstance(element, tuple):  # (200, 299)
                min_status_code, max_status_code = element
                if not isinstance(min_status_code, int):
                    raise ValueError(min_status_code)
                if not isinstance(max_status_code, int):
                    raise ValueError
                max_status_code += 1  # make inclusive
                if max_status_code < min_status_code:
                    raise ValueError(max_status_code)
                for status_code in range(min_status_code, max_status_code):
                    self.status_codes.add(status_code)
            elif isinstance(element, int):  # 200
                self.status_codes.add(element)
            else:
                raise ValueError(element)

    def __call__(
        self,
        request,
        response,
        /,
        *,
        retries: int = 0,
        elapsed: Optional[timedelta] = None,
        **kwargs,
    ) -> bool:
        return response.status_code in self.status_codes



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Session History Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from .utils import randomize

from ..api.sessionhistory.models import ApimodelsAcquiringDS
from ..api.sessionhistory.models import ApimodelsAcquiringDsWaitTime
from ..api.sessionhistory.models import ApimodelsCanceledMatchmakingTicket
from ..api.sessionhistory.models import ApimodelsCreatedMatchmakingTicket
from ..api.sessionhistory.models import ApimodelsEventMatchHistory
from ..api.sessionhistory.models import ApimodelsExpiredMatchmakingTicket
from ..api.sessionhistory.models import ApimodelsGameSessionDetail
from ..api.sessionhistory.models import ApimodelsGameSessionDetailQueryResponse
from ..api.sessionhistory.models import ApimodelsHistory
from ..api.sessionhistory.models import ApimodelsMatchLengthDuration
from ..api.sessionhistory.models import ApimodelsMatchMatchmaking
from ..api.sessionhistory.models import ApimodelsMatchMatchmakingTicket
from ..api.sessionhistory.models import ApimodelsMatchmakingDetail
from ..api.sessionhistory.models import ApimodelsMatchmakingDetailQueryResponse
from ..api.sessionhistory.models import ApimodelsMatchmakingHistory
from ..api.sessionhistory.models import ApimodelsPagination
from ..api.sessionhistory.models import ApimodelsPartyDetail
from ..api.sessionhistory.models import ApimodelsPartyDetailQueryResponse
from ..api.sessionhistory.models import ApimodelsPartyHistory
from ..api.sessionhistory.models import ApimodelsTicketDetailQueryResponse
from ..api.sessionhistory.models import ApimodelsTicketObservabilityDetail
from ..api.sessionhistory.models import ApimodelsTicketObservabilityHistory
from ..api.sessionhistory.models import ApimodelsTotalActiveSession
from ..api.sessionhistory.models import ApimodelsTotalPlayerPersession
from ..api.sessionhistory.models import ApimodelsXRayAcquiringDsQueryResponse
from ..api.sessionhistory.models import ApimodelsXRayAcquiringDsWaitTimeQueryResponse
from ..api.sessionhistory.models import ApimodelsXRayBulkTicketObservabilityRequest
from ..api.sessionhistory.models import ApimodelsXRayBulkTicketObservabilityResponse
from ..api.sessionhistory.models import (
    ApimodelsXRayCanceledMatchmakingTicketQueryResponse,
)
from ..api.sessionhistory.models import (
    ApimodelsXRayCreatedMatchmakingTicketQueryResponse,
)
from ..api.sessionhistory.models import (
    ApimodelsXRayExpiredMatchmakingTicketQueryResponse,
)
from ..api.sessionhistory.models import ApimodelsXRayMatchHistorQueryResponse
from ..api.sessionhistory.models import ApimodelsXRayMatchLengthDurationQueryResponse
from ..api.sessionhistory.models import ApimodelsXRayMatchMatchmakingQueryResponse
from ..api.sessionhistory.models import ApimodelsXRayMatchMatchmakingTicketQueryResponse
from ..api.sessionhistory.models import ApimodelsXRayMatchPoolPodTickMatchResponse
from ..api.sessionhistory.models import ApimodelsXRayMatchPoolPodTickQueryResponse
from ..api.sessionhistory.models import ApimodelsXRayMatchPoolPodTickResult
from ..api.sessionhistory.models import ApimodelsXRayMatchPoolPodTickTicketResponse
from ..api.sessionhistory.models import ApimodelsXRayMatchPoolQueryResponse
from ..api.sessionhistory.models import ApimodelsXRayMatchPoolResult
from ..api.sessionhistory.models import ApimodelsXRayMatchTicketHistory
from ..api.sessionhistory.models import ApimodelsXRayMatchTicketHistoryQueryResponse
from ..api.sessionhistory.models import ApimodelsXRayMatchesQueryResponse
from ..api.sessionhistory.models import ApimodelsXRayTicketMatchesResult
from ..api.sessionhistory.models import ApimodelsXRayTicketObservabilityRequest
from ..api.sessionhistory.models import ApimodelsXRayTicketObservabilityResponse
from ..api.sessionhistory.models import ApimodelsXRayTicketQueryResponse
from ..api.sessionhistory.models import ApimodelsXRayTicketResult
from ..api.sessionhistory.models import ApimodelsXRayTotalActiveSessionQueryResponse
from ..api.sessionhistory.models import (
    ApimodelsXRayTotalPlayerPersessionAVGQueryResponse,
)
from ..api.sessionhistory.models import LogconfigConfiguration
from ..api.sessionhistory.models import ModelsAllianceRule
from ..api.sessionhistory.models import ModelsBackfillProposal
from ..api.sessionhistory.models import ModelsBackfillTicket
from ..api.sessionhistory.models import ModelsDSInformation
from ..api.sessionhistory.models import ModelsGameServer
from ..api.sessionhistory.models import ModelsGameSession
from ..api.sessionhistory.models import ModelsGameSessionTeam
from ..api.sessionhistory.models import ModelsMatch
from ..api.sessionhistory.models import ModelsMatchTicket
from ..api.sessionhistory.models import ModelsMatchingAlly
from ..api.sessionhistory.models import ModelsMatchingParty
from ..api.sessionhistory.models import ModelsMatchingRule
from ..api.sessionhistory.models import ModelsMatchmakingResult
from ..api.sessionhistory.models import ModelsParty
from ..api.sessionhistory.models import ModelsPartyMember
from ..api.sessionhistory.models import ModelsPartyMembers
from ..api.sessionhistory.models import ModelsPartyTeam
from ..api.sessionhistory.models import ModelsPlayerData
from ..api.sessionhistory.models import ModelsProposedProposal
from ..api.sessionhistory.models import ModelsSessionConfig
from ..api.sessionhistory.models import ModelsSessionConfiguration
from ..api.sessionhistory.models import ModelsTeam
from ..api.sessionhistory.models import ModelsTicket
from ..api.sessionhistory.models import ModelsTicketData
from ..api.sessionhistory.models import ModelsTicketObservability
from ..api.sessionhistory.models import ModelsTicketStatus
from ..api.sessionhistory.models import ModelsUser
from ..api.sessionhistory.models import ResponseError


def create_apimodels_acquiring_ds_example() -> ApimodelsAcquiringDS:
    instance = ApimodelsAcquiringDS()
    instance.created_at = randomize("date")
    instance.match_pool = randomize()
    instance.namespace = randomize("slug")
    instance.region = randomize()
    instance.success = randomize("bool")
    instance.value = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_acquiring_ds_wait_time_example() -> ApimodelsAcquiringDsWaitTime:
    instance = ApimodelsAcquiringDsWaitTime()
    instance.created_at = randomize("date")
    instance.match_pool = randomize()
    instance.namespace = randomize("slug")
    instance.value = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_canceled_matchmaking_ticket_example() -> (
    ApimodelsCanceledMatchmakingTicket
):
    instance = ApimodelsCanceledMatchmakingTicket()
    instance.created_at = randomize("date")
    instance.match_pool = randomize()
    instance.namespace = randomize("slug")
    instance.value = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_created_matchmaking_ticket_example() -> (
    ApimodelsCreatedMatchmakingTicket
):
    instance = ApimodelsCreatedMatchmakingTicket()
    instance.created_at = randomize("date")
    instance.match_pool = randomize()
    instance.namespace = randomize("slug")
    instance.value = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_event_match_history_example() -> ApimodelsEventMatchHistory:
    instance = ApimodelsEventMatchHistory()
    instance.action = randomize()
    instance.match_id = randomize()
    instance.matchpool = randomize()
    instance.namespace = randomize("slug")
    instance.pod_name = randomize()
    instance.timestamp = randomize("date")
    instance.match = create_models_match_example()
    instance.rule_set = randomize()
    instance.tick_id = randomize()
    return instance


def create_apimodels_expired_matchmaking_ticket_example() -> (
    ApimodelsExpiredMatchmakingTicket
):
    instance = ApimodelsExpiredMatchmakingTicket()
    instance.created_at = randomize("date")
    instance.match_pool = randomize()
    instance.namespace = randomize("slug")
    instance.value = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_game_session_detail_example() -> ApimodelsGameSessionDetail:
    instance = ApimodelsGameSessionDetail()
    instance.created_at = randomize()
    instance.histories = [create_apimodels_history_example()]
    instance.namespace = randomize("slug")
    instance.session_id = randomize("uid")
    instance.session_template = randomize()
    return instance


def create_apimodels_game_session_detail_query_response_example() -> (
    ApimodelsGameSessionDetailQueryResponse
):
    instance = ApimodelsGameSessionDetailQueryResponse()
    instance.data = [create_apimodels_game_session_detail_example()]
    instance.paging = create_apimodels_pagination_example()
    return instance


def create_apimodels_history_example() -> ApimodelsHistory:
    instance = ApimodelsHistory()
    instance.event_name = randomize()
    instance.payload = create_models_game_session_example()
    instance.timestamp = randomize("date")
    instance.requester_client_id = randomize()
    instance.requester_user_id = randomize()
    return instance


def create_apimodels_match_length_duration_example() -> ApimodelsMatchLengthDuration:
    instance = ApimodelsMatchLengthDuration()
    instance.created_at = randomize("date")
    instance.match_pool = randomize()
    instance.namespace = randomize("slug")
    instance.value = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_match_matchmaking_example() -> ApimodelsMatchMatchmaking:
    instance = ApimodelsMatchMatchmaking()
    instance.created_at = randomize("date")
    instance.match_pool = randomize()
    instance.namespace = randomize("slug")
    instance.value = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_match_matchmaking_ticket_example() -> (
    ApimodelsMatchMatchmakingTicket
):
    instance = ApimodelsMatchMatchmakingTicket()
    instance.created_at = randomize("date")
    instance.match_pool = randomize()
    instance.namespace = randomize("slug")
    instance.value = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_matchmaking_detail_example() -> ApimodelsMatchmakingDetail:
    instance = ApimodelsMatchmakingDetail()
    instance.created_at = randomize("date")
    instance.expired_at = randomize("date")
    instance.game_session_id = randomize()
    instance.histories = [create_apimodels_matchmaking_history_example()]
    instance.match_pool = randomize()
    instance.match_rule = randomize()
    instance.namespace = randomize("slug")
    instance.party_session_id = randomize()
    instance.ticket_id = randomize()
    return instance


def create_apimodels_matchmaking_detail_query_response_example() -> (
    ApimodelsMatchmakingDetailQueryResponse
):
    instance = ApimodelsMatchmakingDetailQueryResponse()
    instance.data = [create_apimodels_matchmaking_detail_example()]
    instance.paging = create_apimodels_pagination_example()
    return instance


def create_apimodels_matchmaking_history_example() -> ApimodelsMatchmakingHistory:
    instance = ApimodelsMatchmakingHistory()
    instance.backfill_proposal = create_models_backfill_proposal_example()
    instance.backfill_ticket = create_models_backfill_ticket_example()
    instance.event_name = randomize()
    instance.requested_user_id = randomize()
    instance.ticket = create_models_ticket_example()
    instance.timestamp = randomize("date")
    instance.unbackfill_reason = randomize()
    return instance


def create_apimodels_pagination_example() -> ApimodelsPagination:
    instance = ApimodelsPagination()
    instance.first = randomize()
    instance.last = randomize()
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_apimodels_party_detail_example() -> ApimodelsPartyDetail:
    instance = ApimodelsPartyDetail()
    instance.created_at = randomize("date")
    instance.histories = [create_apimodels_party_history_example()]
    instance.namespace = randomize("slug")
    instance.party_session_id = randomize()
    instance.session_template = randomize()
    return instance


def create_apimodels_party_detail_query_response_example() -> (
    ApimodelsPartyDetailQueryResponse
):
    instance = ApimodelsPartyDetailQueryResponse()
    instance.data = [create_apimodels_party_detail_example()]
    instance.paging = create_apimodels_pagination_example()
    return instance


def create_apimodels_party_history_example() -> ApimodelsPartyHistory:
    instance = ApimodelsPartyHistory()
    instance.event_name = randomize()
    instance.payload = create_models_party_example()
    instance.timestamp = randomize("date")
    instance.requester_client_id = randomize()
    instance.requester_user_id = randomize()
    return instance


def create_apimodels_ticket_detail_query_response_example() -> (
    ApimodelsTicketDetailQueryResponse
):
    instance = ApimodelsTicketDetailQueryResponse()
    instance.data = [create_apimodels_ticket_observability_detail_example()]
    instance.paging = create_apimodels_pagination_example()
    return instance


def create_apimodels_ticket_observability_detail_example() -> (
    ApimodelsTicketObservabilityDetail
):
    instance = ApimodelsTicketObservabilityDetail()
    instance.action = randomize()
    instance.created_at = randomize("date")
    instance.expired_at = randomize("date")
    instance.game_mode = randomize()
    instance.match_id = randomize()
    instance.namespace = randomize("slug")
    instance.party_id = randomize("uid")
    instance.regions = randomize()
    instance.remaining_tickets = randomize("int", min_val=1, max_val=1000)
    instance.ticket_id = randomize()
    instance.updated_at = randomize("date")
    instance.history = [create_apimodels_ticket_observability_history_example()]
    instance.last_data = create_models_ticket_observability_example()
    instance.remaining_players_per_ticket = [randomize("int", min_val=1, max_val=1000)]
    instance.requested_region = [randomize()]
    instance.ticket = create_models_ticket_example()
    instance.time_to_match_sec = randomize("int", min_val=1, max_val=1000)
    instance.user_i_ds = [randomize()]
    return instance


def create_apimodels_ticket_observability_history_example() -> (
    ApimodelsTicketObservabilityHistory
):
    instance = ApimodelsTicketObservabilityHistory()
    instance.action = randomize()
    instance.expired_at = randomize("date")
    instance.id_ = randomize()
    instance.party_id = randomize("uid")
    instance.payload = {randomize(): randomize()}
    instance.pod_name = randomize()
    instance.tick_id = randomize("int", min_val=1, max_val=1000)
    instance.ticket_id = randomize()
    instance.timestamp = randomize("date")
    return instance


def create_apimodels_total_active_session_example() -> ApimodelsTotalActiveSession:
    instance = ApimodelsTotalActiveSession()
    instance.created_at = randomize("date")
    instance.match_pool = randomize()
    instance.namespace = randomize("slug")
    instance.region = randomize()
    instance.value = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_total_player_persession_example() -> (
    ApimodelsTotalPlayerPersession
):
    instance = ApimodelsTotalPlayerPersession()
    instance.created_at = randomize("date")
    instance.match_pool = randomize()
    instance.namespace = randomize("slug")
    instance.region = randomize()
    instance.value = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_x_ray_acquiring_ds_query_response_example() -> (
    ApimodelsXRayAcquiringDsQueryResponse
):
    instance = ApimodelsXRayAcquiringDsQueryResponse()
    instance.data = [create_apimodels_acquiring_ds_example()]
    return instance


def create_apimodels_x_ray_acquiring_ds_wait_time_query_response_example() -> (
    ApimodelsXRayAcquiringDsWaitTimeQueryResponse
):
    instance = ApimodelsXRayAcquiringDsWaitTimeQueryResponse()
    instance.data = [create_apimodels_acquiring_ds_wait_time_example()]
    return instance


def create_apimodels_x_ray_bulk_ticket_observability_request_example() -> (
    ApimodelsXRayBulkTicketObservabilityRequest
):
    instance = ApimodelsXRayBulkTicketObservabilityRequest()
    instance.ticket_observabilities = [
        create_apimodels_x_ray_ticket_observability_request_example()
    ]
    return instance


def create_apimodels_x_ray_bulk_ticket_observability_response_example() -> (
    ApimodelsXRayBulkTicketObservabilityResponse
):
    instance = ApimodelsXRayBulkTicketObservabilityResponse()
    instance.ticket_i_ds = [randomize()]
    return instance


def create_apimodels_x_ray_canceled_matchmaking_ticket_query_response_example() -> (
    ApimodelsXRayCanceledMatchmakingTicketQueryResponse
):
    instance = ApimodelsXRayCanceledMatchmakingTicketQueryResponse()
    instance.data = [create_apimodels_canceled_matchmaking_ticket_example()]
    return instance


def create_apimodels_x_ray_created_matchmaking_ticket_query_response_example() -> (
    ApimodelsXRayCreatedMatchmakingTicketQueryResponse
):
    instance = ApimodelsXRayCreatedMatchmakingTicketQueryResponse()
    instance.data = [create_apimodels_created_matchmaking_ticket_example()]
    return instance


def create_apimodels_x_ray_expired_matchmaking_ticket_query_response_example() -> (
    ApimodelsXRayExpiredMatchmakingTicketQueryResponse
):
    instance = ApimodelsXRayExpiredMatchmakingTicketQueryResponse()
    instance.data = [create_apimodels_expired_matchmaking_ticket_example()]
    return instance


def create_apimodels_x_ray_match_histor_query_response_example() -> (
    ApimodelsXRayMatchHistorQueryResponse
):
    instance = ApimodelsXRayMatchHistorQueryResponse()
    instance.data = [create_apimodels_event_match_history_example()]
    instance.paging = create_apimodels_pagination_example()
    return instance


def create_apimodels_x_ray_match_length_duration_query_response_example() -> (
    ApimodelsXRayMatchLengthDurationQueryResponse
):
    instance = ApimodelsXRayMatchLengthDurationQueryResponse()
    instance.data = [create_apimodels_match_length_duration_example()]
    return instance


def create_apimodels_x_ray_match_matchmaking_query_response_example() -> (
    ApimodelsXRayMatchMatchmakingQueryResponse
):
    instance = ApimodelsXRayMatchMatchmakingQueryResponse()
    instance.data = [create_apimodels_match_matchmaking_example()]
    return instance


def create_apimodels_x_ray_match_matchmaking_ticket_query_response_example() -> (
    ApimodelsXRayMatchMatchmakingTicketQueryResponse
):
    instance = ApimodelsXRayMatchMatchmakingTicketQueryResponse()
    instance.data = [create_apimodels_match_matchmaking_ticket_example()]
    return instance


def create_apimodels_x_ray_match_pool_pod_tick_match_response_example() -> (
    ApimodelsXRayMatchPoolPodTickMatchResponse
):
    instance = ApimodelsXRayMatchPoolPodTickMatchResponse()
    instance.data = [create_apimodels_event_match_history_example()]
    return instance


def create_apimodels_x_ray_match_pool_pod_tick_query_response_example() -> (
    ApimodelsXRayMatchPoolPodTickQueryResponse
):
    instance = ApimodelsXRayMatchPoolPodTickQueryResponse()
    instance.data = [create_apimodels_x_ray_match_pool_pod_tick_result_example()]
    instance.paging = create_apimodels_pagination_example()
    return instance


def create_apimodels_x_ray_match_pool_pod_tick_result_example() -> (
    ApimodelsXRayMatchPoolPodTickResult
):
    instance = ApimodelsXRayMatchPoolPodTickResult()
    instance.pod_name = randomize()
    instance.tick_id = randomize()
    instance.timestamp = randomize("date")
    instance.total_match_backfilled = randomize("int", min_val=1, max_val=1000)
    instance.total_match_created = randomize("int", min_val=1, max_val=1000)
    instance.total_match_to_backfill = randomize("int", min_val=1, max_val=1000)
    instance.total_ticket_backfilled = randomize("int", min_val=1, max_val=1000)
    instance.total_ticket_for_backfill = randomize("int", min_val=1, max_val=1000)
    instance.total_ticket_for_match = randomize("int", min_val=1, max_val=1000)
    instance.total_ticket_in_queue = randomize("int", min_val=1, max_val=1000)
    instance.total_ticket_matched = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_x_ray_match_pool_pod_tick_ticket_response_example() -> (
    ApimodelsXRayMatchPoolPodTickTicketResponse
):
    instance = ApimodelsXRayMatchPoolPodTickTicketResponse()
    instance.data = [create_models_ticket_status_example()]
    return instance


def create_apimodels_x_ray_match_pool_query_response_example() -> (
    ApimodelsXRayMatchPoolQueryResponse
):
    instance = ApimodelsXRayMatchPoolQueryResponse()
    instance.data = [create_apimodels_x_ray_match_pool_result_example()]
    return instance


def create_apimodels_x_ray_match_pool_result_example() -> ApimodelsXRayMatchPoolResult:
    instance = ApimodelsXRayMatchPoolResult()
    instance.pod_name = randomize()
    return instance


def create_apimodels_x_ray_match_ticket_history_example() -> (
    ApimodelsXRayMatchTicketHistory
):
    instance = ApimodelsXRayMatchTicketHistory()
    instance.action = randomize()
    instance.timestamp = randomize("date")
    instance.match = create_apimodels_event_match_history_example()
    instance.ticket = create_models_ticket_example()
    return instance


def create_apimodels_x_ray_match_ticket_history_query_response_example() -> (
    ApimodelsXRayMatchTicketHistoryQueryResponse
):
    instance = ApimodelsXRayMatchTicketHistoryQueryResponse()
    instance.data = [create_apimodels_x_ray_match_ticket_history_example()]
    return instance


def create_apimodels_x_ray_matches_query_response_example() -> (
    ApimodelsXRayMatchesQueryResponse
):
    instance = ApimodelsXRayMatchesQueryResponse()
    instance.data = [create_apimodels_x_ray_ticket_matches_result_example()]
    return instance


def create_apimodels_x_ray_ticket_matches_result_example() -> (
    ApimodelsXRayTicketMatchesResult
):
    instance = ApimodelsXRayTicketMatchesResult()
    instance.actual_time_to_match = randomize()
    instance.created_at = randomize("date")
    instance.is_pivot = randomize("bool")
    instance.latencies = {}
    instance.match_pool = randomize()
    instance.matched_at = randomize("date")
    instance.namespace = randomize("slug")
    instance.party_session_id = randomize()
    instance.players = [create_models_player_data_example()]
    instance.proposed_proposal = create_models_proposed_proposal_example()
    instance.region_preference = [randomize()]
    instance.ticket_attributes = {randomize(): randomize()}
    instance.ticket_id = randomize()
    instance.time_to_match = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_x_ray_ticket_observability_request_example() -> (
    ApimodelsXRayTicketObservabilityRequest
):
    instance = ApimodelsXRayTicketObservabilityRequest()
    instance.action = randomize()
    instance.game_mode = randomize()
    instance.is_backfill_match = randomize("bool")
    instance.is_rule_set_flexed = randomize("bool")
    instance.namespace = randomize("slug")
    instance.session_tick_id = randomize()
    instance.tick_id = randomize("int", min_val=1, max_val=1000)
    instance.ticket_id = randomize()
    instance.timestamp = randomize("date")
    instance.active_alliance_rule = create_models_alliance_rule_example()
    instance.active_matching_rule = [create_models_matching_rule_example()]
    instance.function = randomize()
    instance.iteration = randomize("int", min_val=1, max_val=1000)
    instance.match_id = randomize()
    instance.remaining_players_per_ticket = [randomize("int", min_val=1, max_val=1000)]
    instance.remaining_tickets = randomize("int", min_val=1, max_val=1000)
    instance.time_to_match_sec = randomize("int", min_val=1, max_val=1000)
    instance.unbackfill_reason = randomize()
    instance.unmatch_reason = randomize()
    return instance


def create_apimodels_x_ray_ticket_observability_response_example() -> (
    ApimodelsXRayTicketObservabilityResponse
):
    instance = ApimodelsXRayTicketObservabilityResponse()
    instance.ticket_id = randomize()
    return instance


def create_apimodels_x_ray_ticket_query_response_example() -> (
    ApimodelsXRayTicketQueryResponse
):
    instance = ApimodelsXRayTicketQueryResponse()
    instance.data = [create_apimodels_x_ray_ticket_result_example()]
    instance.paging = create_apimodels_pagination_example()
    return instance


def create_apimodels_x_ray_ticket_result_example() -> ApimodelsXRayTicketResult:
    instance = ApimodelsXRayTicketResult()
    instance.elapsed_time = randomize("int", min_val=1, max_val=1000)
    instance.id_ = randomize()
    instance.matchpool = randomize()
    instance.pod_name = randomize()
    instance.reason = randomize()
    instance.region = randomize()
    instance.tick_id = randomize()
    instance.ticket_id = randomize()
    instance.ticket_status = randomize()
    instance.timestamp = randomize("date")
    instance.is_backfill = randomize("bool")
    instance.is_pivot = randomize("bool")
    instance.member_attributes = {randomize(): randomize()}
    instance.total_players = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_x_ray_total_active_session_query_response_example() -> (
    ApimodelsXRayTotalActiveSessionQueryResponse
):
    instance = ApimodelsXRayTotalActiveSessionQueryResponse()
    instance.data = [create_apimodels_total_active_session_example()]
    return instance


def create_apimodels_x_ray_total_player_persession_avg_query_response_example() -> (
    ApimodelsXRayTotalPlayerPersessionAVGQueryResponse
):
    instance = ApimodelsXRayTotalPlayerPersessionAVGQueryResponse()
    instance.data = [create_apimodels_total_player_persession_example()]
    return instance


def create_logconfig_configuration_example() -> LogconfigConfiguration:
    instance = LogconfigConfiguration()
    instance.log_level = randomize()
    return instance


def create_models_alliance_rule_example() -> ModelsAllianceRule:
    instance = ModelsAllianceRule()
    instance.max_number = randomize("int", min_val=1, max_val=1000)
    instance.min_number = randomize("int", min_val=1, max_val=1000)
    instance.player_max_number = randomize("int", min_val=1, max_val=1000)
    instance.player_min_number = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_backfill_proposal_example() -> ModelsBackfillProposal:
    instance = ModelsBackfillProposal()
    instance.added_tickets = [create_models_ticket_example()]
    instance.backfill_ticket_id = randomize()
    instance.created_at = randomize("date")
    instance.match_pool = randomize()
    instance.match_session_id = randomize()
    instance.proposal_id = randomize()
    instance.proposed_teams = [create_models_team_example()]
    return instance


def create_models_backfill_ticket_example() -> ModelsBackfillTicket:
    instance = ModelsBackfillTicket()
    instance.created_at = randomize("date")
    instance.match_pool = randomize()
    instance.match_session_id = randomize()
    instance.match_session_version = randomize("int", min_val=1, max_val=1000)
    instance.partial_match = create_models_match_example()
    instance.ticket_id = randomize()
    return instance


def create_models_ds_information_example() -> ModelsDSInformation:
    instance = ModelsDSInformation()
    instance.requested_at = randomize()
    instance.server = create_models_game_server_example()
    instance.status = randomize()
    instance.status_v2 = randomize()
    return instance


def create_models_game_server_example() -> ModelsGameServer:
    instance = ModelsGameServer()
    instance.alternate_ips = [randomize()]
    instance.custom_attribute = randomize()
    instance.deployment = randomize()
    instance.game_version = randomize("version")
    instance.image_version = randomize()
    instance.ip = randomize()
    instance.is_override_game_version = randomize("bool")
    instance.last_update = randomize("date")
    instance.namespace = randomize("slug")
    instance.pod_name = randomize()
    instance.port = randomize("int", min_val=1, max_val=1000)
    instance.ports = {}
    instance.protocol = randomize()
    instance.provider = randomize()
    instance.region = randomize()
    instance.session_id = randomize("uid")
    instance.status = randomize()
    return instance


def create_models_game_session_example() -> ModelsGameSession:
    instance = ModelsGameSession()
    instance.attributes = {randomize(): randomize()}
    instance.backfill_ticket_id = randomize()
    instance.code = randomize()
    instance.configuration = create_models_session_config_example()
    instance.configuration_name = randomize()
    instance.created_at = randomize()
    instance.created_by = randomize()
    instance.ds_information = create_models_ds_information_example()
    instance.game_mode = randomize()
    instance.id_ = randomize()
    instance.is_active = randomize("bool")
    instance.is_full = randomize("bool")
    instance.leader_id = randomize()
    instance.match_pool = randomize()
    instance.members = [create_models_user_example()]
    instance.namespace = randomize("slug")
    instance.processing_time = randomize("int", min_val=1, max_val=1000)
    instance.teams = [create_models_game_session_team_example()]
    instance.ticket_i_ds = [randomize()]
    instance.updated_at = randomize()
    instance.version = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_game_session_team_example() -> ModelsGameSessionTeam:
    instance = ModelsGameSessionTeam()
    instance.parties = [create_models_party_members_example()]
    instance.user_i_ds = [randomize()]
    return instance


def create_models_match_example() -> ModelsMatch:
    instance = ModelsMatch()
    instance.backfill = randomize("bool")
    instance.client_version = randomize()
    instance.match_attributes = {randomize(): randomize()}
    instance.pivot_id = randomize()
    instance.region_preference = [randomize()]
    instance.server_name = randomize()
    instance.teams = [create_models_team_example()]
    instance.tickets = [create_models_match_ticket_example()]
    instance.timestamp = randomize("date")
    return instance


def create_models_match_ticket_example() -> ModelsMatchTicket:
    instance = ModelsMatchTicket()
    instance.actual_time_to_match = randomize()
    instance.created_at = randomize("date")
    instance.is_pivot = randomize("bool")
    instance.latencies = {}
    instance.match_pool = randomize()
    instance.matched_at = randomize("date")
    instance.namespace = randomize("slug")
    instance.party_session_id = randomize()
    instance.players = [create_models_player_data_example()]
    instance.proposed_proposal = create_models_proposed_proposal_example()
    instance.region_preference = [randomize()]
    instance.ticket_attributes = {randomize(): randomize()}
    instance.ticket_id = randomize()
    instance.time_to_match = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_matching_ally_example() -> ModelsMatchingAlly:
    instance = ModelsMatchingAlly()
    instance.matching_parties = [create_models_matching_party_example()]
    return instance


def create_models_matching_party_example() -> ModelsMatchingParty:
    instance = ModelsMatchingParty()
    instance.first_ticket_created_at = randomize("int", min_val=1, max_val=1000)
    instance.party_id = randomize("uid")
    instance.party_members = [create_models_party_member_example()]
    instance.ticket_id = randomize()
    instance.party_attributes = {randomize(): randomize()}
    return instance


def create_models_matching_rule_example() -> ModelsMatchingRule:
    instance = ModelsMatchingRule()
    instance.attribute = randomize()
    instance.criteria = randomize()
    instance.reference = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_matchmaking_result_example() -> ModelsMatchmakingResult:
    instance = ModelsMatchmakingResult()
    instance.match_id = randomize()
    instance.matching_allies = [create_models_matching_ally_example()]
    instance.queued_at = randomize("int", min_val=1, max_val=1000)
    instance.ticket_id = randomize()
    instance.updated_at = randomize("date")
    instance.channel = randomize()
    instance.client_version = randomize()
    instance.deployment = randomize()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    instance.game_mode = randomize()
    instance.joinable = randomize("bool")
    instance.match_session_id = randomize()
    instance.namespace = randomize("slug")
    instance.party_attributes = {randomize(): randomize()}
    instance.party_id = randomize("uid")
    instance.region = randomize()
    instance.server_name = randomize()
    instance.status = randomize()
    return instance


def create_models_party_example() -> ModelsParty:
    instance = ModelsParty()
    instance.attributes = {randomize(): randomize()}
    instance.code = randomize()
    instance.configuration = create_models_session_configuration_example()
    instance.configuration_name = randomize()
    instance.created_at = randomize("date")
    instance.created_by = randomize()
    instance.expired_at = randomize("date")
    instance.id_ = randomize()
    instance.is_active = randomize("bool")
    instance.is_full = randomize("bool")
    instance.leader_id = randomize()
    instance.members = [create_models_user_example()]
    instance.namespace = randomize("slug")
    instance.updated_at = randomize("date")
    instance.version = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_party_member_example() -> ModelsPartyMember:
    instance = ModelsPartyMember()
    instance.user_id = randomize("uid")
    instance.extra_attributes = {randomize(): randomize()}
    return instance


def create_models_party_members_example() -> ModelsPartyMembers:
    instance = ModelsPartyMembers()
    instance.party_id = randomize("uid")
    instance.user_i_ds = [randomize()]
    return instance


def create_models_party_team_example() -> ModelsPartyTeam:
    instance = ModelsPartyTeam()
    instance.party_id = randomize("uid")
    instance.user_i_ds = [randomize()]
    return instance


def create_models_player_data_example() -> ModelsPlayerData:
    instance = ModelsPlayerData()
    instance.attributes = {randomize(): randomize()}
    instance.party_id = randomize("uid")
    instance.platform_id = randomize()
    instance.player_id = randomize()
    return instance


def create_models_proposed_proposal_example() -> ModelsProposedProposal:
    instance = ModelsProposedProposal()
    instance.backfill_id = randomize()
    instance.proposal_id = randomize()
    instance.status = randomize()
    return instance


def create_models_session_config_example() -> ModelsSessionConfig:
    instance = ModelsSessionConfig()
    instance.client_version = randomize()
    instance.deployment = randomize()
    instance.inactive_timeout = randomize("int", min_val=1, max_val=1000)
    instance.invite_timeout = randomize("int", min_val=1, max_val=1000)
    instance.joinability = randomize()
    instance.max_players = randomize("int", min_val=1, max_val=1000)
    instance.min_players = randomize("int", min_val=1, max_val=1000)
    instance.name = randomize()
    instance.persistent = randomize("bool")
    instance.requested_regions = [randomize()]
    instance.type_ = randomize()
    return instance


def create_models_session_configuration_example() -> ModelsSessionConfiguration:
    instance = ModelsSessionConfiguration()
    instance.client_version = randomize()
    instance.deployment = randomize()
    instance.inactive_timeout = randomize("int", min_val=1, max_val=1000)
    instance.invite_timeout = randomize("int", min_val=1, max_val=1000)
    instance.joinability = randomize()
    instance.max_players = randomize("int", min_val=1, max_val=1000)
    instance.min_players = randomize("int", min_val=1, max_val=1000)
    instance.persistent = randomize("bool")
    instance.requested_regions = [randomize()]
    instance.text_chat = randomize("bool")
    instance.type_ = randomize()
    return instance


def create_models_team_example() -> ModelsTeam:
    instance = ModelsTeam()
    instance.parties = [create_models_party_team_example()]
    instance.user_i_ds = [randomize()]
    return instance


def create_models_ticket_example() -> ModelsTicket:
    instance = ModelsTicket()
    instance.created_at = randomize("date")
    instance.latencies = {}
    instance.match_pool = randomize()
    instance.matched_at = randomize("date")
    instance.namespace = randomize("slug")
    instance.party_session_id = randomize()
    instance.players = [create_models_player_data_example()]
    instance.proposed_proposal = create_models_proposed_proposal_example()
    instance.ticket_attributes = {randomize(): randomize()}
    instance.ticket_id = randomize()
    return instance


def create_models_ticket_data_example() -> ModelsTicketData:
    instance = ModelsTicketData()
    instance.action = randomize()
    instance.game_mode = randomize()
    instance.is_backfill_match = randomize("bool")
    instance.is_pivot = randomize("bool")
    instance.is_rule_set_flexed = randomize("bool")
    instance.matched_region = randomize()
    instance.member_attributes = {randomize(): randomize()}
    instance.namespace = randomize("slug")
    instance.party_id = randomize("uid")
    instance.pod_name = randomize()
    instance.session_tick_id = randomize()
    instance.tick_id = randomize("int", min_val=1, max_val=1000)
    instance.timestamp = randomize("date")
    instance.total_players = randomize("int", min_val=1, max_val=1000)
    instance.active_alliance_rule = create_models_alliance_rule_example()
    instance.active_matching_rule = [create_models_matching_rule_example()]
    instance.elapsed_time = randomize("int", min_val=1, max_val=1000)
    instance.function = randomize()
    instance.iteration = randomize("int", min_val=1, max_val=1000)
    instance.match_id = randomize()
    instance.remaining_players_per_ticket = [randomize("int", min_val=1, max_val=1000)]
    instance.remaining_tickets = randomize("int", min_val=1, max_val=1000)
    instance.session = create_models_matchmaking_result_example()
    instance.time_to_match_sec = randomize("int", min_val=1, max_val=1000)
    instance.unbackfill_reason = randomize()
    instance.unmatch_reason = randomize()
    return instance


def create_models_ticket_observability_example() -> ModelsTicketObservability:
    instance = ModelsTicketObservability()
    instance.ticket = create_models_ticket_data_example()
    return instance


def create_models_ticket_status_example() -> ModelsTicketStatus:
    instance = ModelsTicketStatus()
    instance.matched = randomize("bool")
    instance.ticket = create_models_ticket_example()
    return instance


def create_models_user_example() -> ModelsUser:
    instance = ModelsUser()
    instance.id_ = randomize()
    instance.platform_id = randomize()
    instance.platform_user_id = randomize()
    instance.status = randomize()
    instance.status_v2 = randomize()
    instance.updated_at = randomize()
    return instance


def create_response_error_example() -> ResponseError:
    instance = ResponseError()
    instance.attributes = {randomize(): randomize()}
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    instance.message = randomize()
    instance.name = randomize()
    return instance



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import deprecated
from ....core import same_doc_as

from ..models import GrpcServerInfo
from ..models import LootBoxPluginConfigInfo
from ..models import LootBoxPluginConfigUpdate
from ..models import RevocationPluginConfigInfo
from ..models import RevocationPluginConfigUpdate
from ..models import SectionPluginConfigInfo
from ..models import SectionPluginConfigUpdate
from ..models import ServicePluginConfigInfo
from ..models import ServicePluginConfigUpdate
from ..models import ValidationErrorEntity

from ..operations.service_plugin_config import DeleteLootBoxPluginConfig
from ..operations.service_plugin_config import DeleteRevocationPluginConfig
from ..operations.service_plugin_config import DeleteSectionPluginConfig
from ..operations.service_plugin_config import DeleteServicePluginConfig
from ..operations.service_plugin_config import GetLootBoxGrpcInfo
from ..operations.service_plugin_config import GetLootBoxPluginConfig
from ..operations.service_plugin_config import GetRevocationPluginConfig
from ..operations.service_plugin_config import GetSectionPluginConfig
from ..operations.service_plugin_config import GetServicePluginConfig
from ..operations.service_plugin_config import UpdateLootBoxPluginConfig
from ..operations.service_plugin_config import UpdateRevocationPluginConfig
from ..operations.service_plugin_config import UpdateSectionPluginConfig
from ..operations.service_plugin_config import UpdateServicePluginConfig
from ..operations.service_plugin_config import UploadRevocationPluginConfigCert
from ..operations.service_plugin_config import UploadSectionPluginConfigCert
from ..operations.service_plugin_config import UplodLootBoxPluginConfigCert
from ..models import GrpcServerInfoConnectionTypeEnumEnum
from ..models import LootBoxPluginConfigInfoExtendTypeEnum
from ..models import LootBoxPluginConfigUpdateExtendTypeEnum
from ..models import RevocationPluginConfigInfoExtendTypeEnum
from ..models import RevocationPluginConfigUpdateExtendTypeEnum
from ..models import SectionPluginConfigInfoExtendTypeEnum
from ..models import SectionPluginConfigUpdateExtendTypeEnum


@same_doc_as(DeleteLootBoxPluginConfig)
def delete_loot_box_plugin_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete lootbox plugin config (deleteLootBoxPluginConfig)

    Delete service plugin config.

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/lootbox

        method: DELETE

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Delete successfully)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteLootBoxPluginConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteLootBoxPluginConfig)
async def delete_loot_box_plugin_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete lootbox plugin config (deleteLootBoxPluginConfig)

    Delete service plugin config.

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/lootbox

        method: DELETE

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Delete successfully)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteLootBoxPluginConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteRevocationPluginConfig)
def delete_revocation_plugin_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete revocation plugin config (deleteRevocationPluginConfig)

    Delete service plugin config.

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/plugins/revocation

        method: DELETE

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Delete successfully)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteRevocationPluginConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteRevocationPluginConfig)
async def delete_revocation_plugin_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete revocation plugin config (deleteRevocationPluginConfig)

    Delete service plugin config.

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/plugins/revocation

        method: DELETE

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Delete successfully)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteRevocationPluginConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteSectionPluginConfig)
def delete_section_plugin_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete section plugin config (deleteSectionPluginConfig)

    Delete section plugin config.

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/section

        method: DELETE

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Delete successfully)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteSectionPluginConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteSectionPluginConfig)
async def delete_section_plugin_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete section plugin config (deleteSectionPluginConfig)

    Delete section plugin config.

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/section

        method: DELETE

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Delete successfully)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteSectionPluginConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(DeleteServicePluginConfig)
def delete_service_plugin_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete service plugin config (deleteServicePluginConfig)

    Delete service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/configs/servicePlugin

        method: DELETE

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Delete successfully)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteServicePluginConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(DeleteServicePluginConfig)
async def delete_service_plugin_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete service plugin config (deleteServicePluginConfig)

    Delete service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/configs/servicePlugin

        method: DELETE

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Delete successfully)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteServicePluginConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetLootBoxGrpcInfo)
def get_loot_box_grpc_info(
    force: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get lootbox plugin gRPC info (getLootBoxGrpcInfo)

    Get lootbox plugin gRPC info.

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/lootbox/grpcInfo

        method: GET

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        force: (force) OPTIONAL bool in query

    Responses:
        200: OK - GrpcServerInfo (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetLootBoxGrpcInfo.create(
        force=force,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetLootBoxGrpcInfo)
async def get_loot_box_grpc_info_async(
    force: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get lootbox plugin gRPC info (getLootBoxGrpcInfo)

    Get lootbox plugin gRPC info.

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/lootbox/grpcInfo

        method: GET

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        force: (force) OPTIONAL bool in query

    Responses:
        200: OK - GrpcServerInfo (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetLootBoxGrpcInfo.create(
        force=force,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetLootBoxPluginConfig)
def get_loot_box_plugin_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get lootbox plugin config (getLootBoxPluginConfig)

    Get lootbox plugin config.

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/lootbox

        method: GET

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - LootBoxPluginConfigInfo (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetLootBoxPluginConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetLootBoxPluginConfig)
async def get_loot_box_plugin_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get lootbox plugin config (getLootBoxPluginConfig)

    Get lootbox plugin config.

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/lootbox

        method: GET

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - LootBoxPluginConfigInfo (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetLootBoxPluginConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetRevocationPluginConfig)
def get_revocation_plugin_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get revocation plugin config (getRevocationPluginConfig)

    Get revocation plugin config.

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/plugins/revocation

        method: GET

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - RevocationPluginConfigInfo (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetRevocationPluginConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetRevocationPluginConfig)
async def get_revocation_plugin_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get revocation plugin config (getRevocationPluginConfig)

    Get revocation plugin config.

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/plugins/revocation

        method: GET

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - RevocationPluginConfigInfo (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetRevocationPluginConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetSectionPluginConfig)
def get_section_plugin_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get section plugin config (getSectionPluginConfig)

    Get section plugin config.

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/section

        method: GET

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - SectionPluginConfigInfo (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetSectionPluginConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetSectionPluginConfig)
async def get_section_plugin_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get section plugin config (getSectionPluginConfig)

    Get section plugin config.

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/section

        method: GET

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - SectionPluginConfigInfo (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetSectionPluginConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(GetServicePluginConfig)
def get_service_plugin_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get service plugin config (getServicePluginConfig)

    Get service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/configs/servicePlugin

        method: GET

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ServicePluginConfigInfo (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetServicePluginConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(GetServicePluginConfig)
async def get_service_plugin_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get service plugin config (getServicePluginConfig)

    Get service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/configs/servicePlugin

        method: GET

        tags: ["ServicePluginConfig"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ServicePluginConfigInfo (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetServicePluginConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateLootBoxPluginConfig)
def update_loot_box_plugin_config(
    body: LootBoxPluginConfigUpdate,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update lootbox plugin config (updateLootBoxPluginConfig)

    Update lootbox plugin config. Other detail info:

      * Returns : updated service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/lootbox

        method: PUT

        tags: ["ServicePluginConfig"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED LootBoxPluginConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - LootBoxPluginConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateLootBoxPluginConfig.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateLootBoxPluginConfig)
async def update_loot_box_plugin_config_async(
    body: LootBoxPluginConfigUpdate,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update lootbox plugin config (updateLootBoxPluginConfig)

    Update lootbox plugin config. Other detail info:

      * Returns : updated service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/lootbox

        method: PUT

        tags: ["ServicePluginConfig"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED LootBoxPluginConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - LootBoxPluginConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateLootBoxPluginConfig.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateRevocationPluginConfig)
def update_revocation_plugin_config(
    body: RevocationPluginConfigUpdate,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update revocation plugin config (updateRevocationPluginConfig)

    Update revocation plugin config. Other detail info:

      * Returns : updated service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/plugins/revocation

        method: PUT

        tags: ["ServicePluginConfig"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED RevocationPluginConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - RevocationPluginConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateRevocationPluginConfig.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateRevocationPluginConfig)
async def update_revocation_plugin_config_async(
    body: RevocationPluginConfigUpdate,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update revocation plugin config (updateRevocationPluginConfig)

    Update revocation plugin config. Other detail info:

      * Returns : updated service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/plugins/revocation

        method: PUT

        tags: ["ServicePluginConfig"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED RevocationPluginConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - RevocationPluginConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateRevocationPluginConfig.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateSectionPluginConfig)
def update_section_plugin_config(
    body: SectionPluginConfigUpdate,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update section plugin config (updateSectionPluginConfig)

    Update section config. Other detail info:

      * Returns : updated service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/section

        method: PUT

        tags: ["ServicePluginConfig"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED SectionPluginConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - SectionPluginConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateSectionPluginConfig.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateSectionPluginConfig)
async def update_section_plugin_config_async(
    body: SectionPluginConfigUpdate,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update section plugin config (updateSectionPluginConfig)

    Update section config. Other detail info:

      * Returns : updated service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/section

        method: PUT

        tags: ["ServicePluginConfig"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED SectionPluginConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - SectionPluginConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateSectionPluginConfig.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(UpdateServicePluginConfig)
def update_service_plugin_config(
    body: ServicePluginConfigUpdate,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update service plugin config service (updateServicePluginConfig)

    Update catalog config. Other detail info:

      * Returns : updated service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/configs/servicePlugin

        method: PUT

        tags: ["ServicePluginConfig"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ServicePluginConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ServicePluginConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateServicePluginConfig.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(UpdateServicePluginConfig)
async def update_service_plugin_config_async(
    body: ServicePluginConfigUpdate,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update service plugin config service (updateServicePluginConfig)

    Update catalog config. Other detail info:

      * Returns : updated service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/configs/servicePlugin

        method: PUT

        tags: ["ServicePluginConfig"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ServicePluginConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ServicePluginConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateServicePluginConfig.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UploadRevocationPluginConfigCert)
def upload_revocation_plugin_config_cert(
    file: Optional[Any] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Upload revocation plugin custom config tls cert (uploadRevocationPluginConfigCert)

    Upload revocation plugin custom config tls cert.Other detail info:

      * Returns : updated service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/plugins/revocation/revocation/customConfig/cert

        method: PUT

        tags: ["ServicePluginConfig"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        file: (file) OPTIONAL Any in form_data

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - RevocationPluginConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UploadRevocationPluginConfigCert.create(
        file=file,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UploadRevocationPluginConfigCert)
async def upload_revocation_plugin_config_cert_async(
    file: Optional[Any] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Upload revocation plugin custom config tls cert (uploadRevocationPluginConfigCert)

    Upload revocation plugin custom config tls cert.Other detail info:

      * Returns : updated service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/plugins/revocation/revocation/customConfig/cert

        method: PUT

        tags: ["ServicePluginConfig"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        file: (file) OPTIONAL Any in form_data

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - RevocationPluginConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UploadRevocationPluginConfigCert.create(
        file=file,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UploadSectionPluginConfigCert)
def upload_section_plugin_config_cert(
    file: Optional[Any] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Upload section plugin custom config tls cert (uploadSectionPluginConfigCert)

    Upload section plugin custom config tls cert.Other detail info:

      * Returns : updated service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/section/customConfig/cert

        method: PUT

        tags: ["ServicePluginConfig"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        file: (file) OPTIONAL Any in form_data

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - SectionPluginConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UploadSectionPluginConfigCert.create(
        file=file,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UploadSectionPluginConfigCert)
async def upload_section_plugin_config_cert_async(
    file: Optional[Any] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Upload section plugin custom config tls cert (uploadSectionPluginConfigCert)

    Upload section plugin custom config tls cert.Other detail info:

      * Returns : updated service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/section/customConfig/cert

        method: PUT

        tags: ["ServicePluginConfig"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        file: (file) OPTIONAL Any in form_data

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - SectionPluginConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UploadSectionPluginConfigCert.create(
        file=file,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UplodLootBoxPluginConfigCert)
def uplod_loot_box_plugin_config_cert(
    file: Optional[Any] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Upload lootbox plugin custom config tls cert (uplodLootBoxPluginConfigCert)

    Upload lootbox plugin custom config tls cert.Other detail info:

      * Returns : updated service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/lootbox/customConfig/cert

        method: PUT

        tags: ["ServicePluginConfig"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        file: (file) OPTIONAL Any in form_data

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - LootBoxPluginConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UplodLootBoxPluginConfigCert.create(
        file=file,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UplodLootBoxPluginConfigCert)
async def uplod_loot_box_plugin_config_cert_async(
    file: Optional[Any] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Upload lootbox plugin custom config tls cert (uplodLootBoxPluginConfigCert)

    Upload lootbox plugin custom config tls cert.Other detail info:

      * Returns : updated service plugin config

    Properties:
        url: /platform/admin/namespaces/{namespace}/catalog/plugins/lootbox/customConfig/cert

        method: PUT

        tags: ["ServicePluginConfig"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        file: (file) OPTIONAL Any in form_data

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - LootBoxPluginConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UplodLootBoxPluginConfigCert.create(
        file=file,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )
